@@ -1486,6 +1486,7 @@ int main( int argc, char **argv )
 
   QTextStream h( &header );
 
+  h.setCodec("utf-8");
   h << "// This file is generated by kconfig_compiler from " << QFileInfo(inputFilename).fileName() << "." << endl;
   h << "// All changes you do to this file will be lost." << endl;
 
@@ -1908,7 +1909,7 @@ int main( int argc, char **argv )
 
   QTextStream cpp( &implementation );
 
-
+  cpp.setCodec("utf-8");
   cpp << "// This file is generated by kconfig_compiler from " << QFileInfo(inputFilename).fileName() << "." << endl;
   cpp << "// All changes you do to this file will be lost." << endl << endl;
 
